---
test_data: TD_43_24_76_58
test_title: single value multiple envelopes
---

Implicit value (see FS_13_51_07_97) is supposed to set when there is any number of `data_envelope`-s,
which have the same arg value for all.

There is no point to suggest a value if it is the only one possible.

This data populates only `ServiceArgType.CodeMaturity` set to `dev` for all `data_envelope`-s.
